@@ -17,6 +17,8 @@
 #ifndef CHOOSEFILEBUTTON_H
 #define CHOOSEFILEBUTTON_H
 
+#include "imagefile.h"
+
 #include <QPushButton>
 
 
@@ -27,13 +29,17 @@ class ChooseFileButton : public QPushButton
 public:
     enum FilterType {
         ImageFilter,
-        SoundFilter
+        SoundFilter,
+        NoFilter
     };
 
-    explicit ChooseFileButton(FilterType filter, QWidget *parent = 0);
+    explicit ChooseFileButton(QWidget *parent = 0);
+    explicit ChooseFileButton(FilterType filter=NoFilter, QWidget *parent = 0);
     QString filePath();
     void setFilePath(const QString&);
+    void setImageFile(ImageFile*);
     bool hasValidFile();
+    void setFilter(FilterType);
 
 signals:
     void fileSelected(const QString&);
@@ -44,10 +50,12 @@ public slots:
 
 private:
     QString mFilePath;
+    QString mPreviousPath;
     QString mFilters;
     QStringList mImageExtensions;
     QStringList mSoundExtensions;
     FilterType mActiveFilter;
+    void init(FilterType);
 
 };
 
