@@ -207,6 +207,7 @@ void DrawingSurfaceWidget::paintSceneTo(QPaintDevice * paintDevice)
         return;
 
     QPainter painter(paintDevice);
+    painter.setRenderHint(QPainter::SmoothPixmapTransform, true);
     scene->paint(painter);
     drawSelection(painter, scene->selectedObject());
 }
@@ -262,8 +263,13 @@ void DrawingSurfaceWidget::mousePressEvent ( QMouseEvent * event )
         mMoving = true;
     }
 
-    bool scene = !mObject && !object;
-    emit selectionChanged(object, scene);
+    if (object)
+        emit selectionChanged(object);
+    else if (mObject)
+        emit selectionChanged(mObject);
+    else
+        emit selectionChanged(0);
+
     update();
 
     QWidget::mousePressEvent(event);
