@@ -438,19 +438,25 @@ void Object::setType(const QString & type)
 
 void Object::paint(QPainter & painter)
 {
-    painter.setOpacity(opacityF());
-
+    QRect rect(mSceneRect.x(), mSceneRect.y(), contentWidth(), contentHeight());
     if (! mVisible || ! mOpacity) {
+        QPen pen(Qt::white);
+        painter.setOpacity(0.5);
+        pen.setWidth(3);
+        painter.setPen(pen);
+        painter.drawRect(rect);
+        painter.setOpacity(0);
         return;
     }
 
     painter.setOpacity(opacityF());
-    QRect rect(mSceneRect.x(), mSceneRect.y(), contentWidth(), contentHeight());
-
     mBackground.paint(painter, rect, mCornerRadius, opacityF());
 
     if (mBorderColor.isValid()) {
-        painter.setPen(QPen(mBorderColor, mBorderWidth));
+        if (mBorderWidth)
+            painter.setPen(QPen(mBorderColor, mBorderWidth));
+        else
+            painter.setPen(Qt::NoPen);
         if (mCornerRadius)
             painter.drawRoundedRect(rect, mCornerRadius, mCornerRadius);
         else
