@@ -119,9 +119,17 @@ SceneEditorWidget* Scene::editorWidget()
     return mEditorWidget;
 }
 
-QList<Object*> Scene::objects()
+QList<Object*> Scene::objects(const QString& type)
 {
-    return mObjects;
+    if (type.isEmpty())
+        return mObjects;
+
+    QList<Object*> objects;
+    for(int i=0; i < mObjects.size(); i++)
+        if (mObjects[i]->type() == type)
+            objects.append(mObjects[i]);
+
+    return objects;
 }
 
 QList<Object*> Scene::temporaryObjects()
@@ -177,8 +185,19 @@ void Scene::appendObject(Object* object, bool select, bool temporarily)
 
     if (temporarily)
         mTemporaryObjects.append(object);
-    else
-        mObjects.append(object);
+    else {
+        if (object->type() == "TextBox" || object->type() == "DialogueBox" || object->type() == "Button")
+            mObjects.append(object);
+        else { //set TextBox/DialogueBox/Button over any other object by default
+            int i=mObjects.size()-1;
+            while(i > 0 && (mObjects[i]->type() == "TextBox" || mObjects[i]->type() == "DialogueBox" || mObjects[i]->type() == "Button"))
+                --i;
+            mObjects.insert(i, object);
+        }
+    }
+
+    if (! temporarily)
+        emit objectAdded(object);
 
     if (select)
         selectObject(object);
@@ -376,6 +395,11 @@ QString Scene::backgroundPath()
     return "";
 }
 
+ImageFile* Scene::background() const
+{
+    return mBackgroundImage;
+}
+
 void Scene::clearBackground()
 {
     if ( mBackgroundImage ) {
@@ -422,6 +446,7 @@ void Scene::removeObject(Object* object, bool del, bool temporary)
         removed = mObjects.removeOne(object);
 
     if (removed) {
+        emit objectRemoved(object);
         if (selectedObject() == object)
             selectObject(0);
         object->disconnect(this);
@@ -490,18 +515,20 @@ void Scene::setActions(const QList<Action *> & actions)
 }
 
 void Scene::appendAction(Action * action, bool copy)
+{
+    insertAction(mActions.size(), action, copy);
+}
+
+void Scene::insertAction(int row, Action* action, bool copy)
 {
     if (! action)
         return;
 
-    if (copy) {
+    if (copy)
         action = ActionInfoManager::typeToAction(action->toJsonObject(), this);
-    }
-    else {
+    else
         action->setParent(this);
-    }
-
-    mActions.append(action);
+    mActions.insert(row, action);
     emit actionAdded(action);
 }
 
@@ -569,11 +596,6 @@ Scene* Scene::copy()
     return scene;
 }
 
-void Scene::insertAction(int row, Action* action)
-{
-    mActions.insert(row, action);
-}
-
 bool Scene::isValidObjectName(const QString& name)
 {
     if (name.isEmpty() || name.isNull())
@@ -663,7 +685,7 @@ void Scene::paint(QPainter & painter)
 
     for (int i=0; i < objects.size(); i++) {
         object = objects.at(i);
-        if (object && object->visible()){
+        if (object){
             painter.save();
             object->paint(painter);
             painter.restore();
